@@ -1,7 +1,7 @@
 #!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002-2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is the install script for eric6.
 
@@ -9,8 +9,7 @@
 Installation script for the eric6 IDE and all eric6 related tools.
 """
 
-from __future__ import unicode_literals
-from __future__ import print_function
+from __future__ import unicode_literals, print_function
 try:
     import cStringIO as io
     import sip
@@ -470,10 +469,11 @@ def cleanupSource(dirName):
             if os.path.exists(os.path.join(dirName, sourceName + "c")):
                 os.remove(os.path.join(dirName, sourceName + "c"))
     
-    # step 2: delete the __pycache__ directory and all *.pyc files
+    # step 2: delete the __pycache__ directory and all remaining *.pyc files
     if os.path.exists(os.path.join(dirName, "__pycache__")):
         shutil.rmtree(os.path.join(dirName, "__pycache__"))
-    for name in [f for f in dirListing if fnmatch.fnmatch(f, "*.pyc")]:
+    for name in [f for f in os.listdir(dirName)
+                 if fnmatch.fnmatch(f, "*.pyc")]:
         os.remove(os.path.join(dirName, name))
     
     # step 3: descent into subdirectories and delete them if empty
@@ -738,7 +738,7 @@ def installEric():
         try:
             shutilCopy(name, cfg['ericDocDir'])
         except EnvironmentError:
-            print("Could not install '{1}'.".format(name))
+            print("Could not install '{0}'.".format(name))
    
     # copy some more stuff
     for name in ['default.e4k', 'default_Mac.e4k']:
@@ -900,10 +900,13 @@ def createMacAppBundle(pydir):
     if path:
         pybin = os.path.join(sys.exec_prefix, "bin")
         pathlist = path.split(os.pathsep)
-        if pybin not in pathlist:
-            pathLine = "PATH={0}{1}{2}\n".format(pybin, os.pathsep, path)
-        else:
-            pathLine = "PATH={0}\n".format(path)
+        pathlist_n = [pybin]
+        for path_ in pathlist:
+            if path_ and path_ not in pathlist_n:
+                pathlist_n.append(path_)
+        pathLine = "PATH={0}\n".format(os.pathsep.join(pathlist_n))
+    
+    # create the wrapper script
     wrapper = ('''#!/bin/sh\n'''
                '''\n'''
                '''{0}'''
@@ -1062,10 +1065,10 @@ def doDependancyChecks():
     print("Python Version: {0:d}.{1:d}.{2:d}".format(*sys.version_info[:3]))
     if sys.version_info < (2, 7, 0):
         print('Sorry, you must have Python 2.7.0 or higher or '
-              'Python 3.1.0 or higher.')
+              'Python 3.3.0 or higher.')
         exit(5)
-    elif sys.version_info < (3, 1, 0) and sys.version_info[0] == 3:
-        print('Sorry, you must have Python 3.1.0 or higher.')
+    elif sys.version_info < (3, 3, 0) and sys.version_info[0] == 3:
+        print('Sorry, you must have Python 3.3.0 or higher.')
         exit(5)
     if sys.version_info > (3, 9, 9):
         print('Sorry, eric6 requires Python 3 or Python 2 for running.')
@@ -1095,6 +1098,19 @@ def doDependancyChecks():
             exit(1)
         print("Found PyQt5")
     
+    try:
+        if pyqtVariant == "PyQt4":
+            pyuic = "pyuic4"
+            from PyQt4 import uic      # __IGNORE_WARNING__
+        else:
+            pyuic = "pyuic5"
+            from PyQt5 import uic      # __IGNORE_WARNING__
+    except ImportError as msg:
+        print("Sorry, {0} is not installed.".format(pyuic))
+        print('Error: {0}'.format(msg))
+        exit(1)
+    print("Found {0}".format(pyuic))
+    
     try:
         if pyqtVariant == "PyQt4":
             from PyQt4 import Qsci      # __IGNORE_WARNING__
@@ -1110,13 +1126,12 @@ def doDependancyChecks():
     if pyqtVariant == "PyQt4":
         impModulesList = [
             "PyQt4.QtGui", "PyQt4.QtNetwork", "PyQt4.QtSql",
-            "PyQt4.QtSvg", "PyQt4.QtWebKit",
+            "PyQt4.QtSvg",
         ]
     else:
         impModulesList = [
             "PyQt5.QtGui", "PyQt5.QtNetwork", "PyQt5.QtPrintSupport",
-            "PyQt5.QtSql", "PyQt5.QtSvg", "PyQt5.QtWebKit",
-            "PyQt5.QtWebKitWidgets", "PyQt5.QtWidgets",
+            "PyQt5.QtSql", "PyQt5.QtSvg", "PyQt5.QtWidgets",
         ]
     modulesOK = True
     for impModule in impModulesList:
@@ -1155,8 +1170,8 @@ def doDependancyChecks():
         import sip
         sipVersion = sip.SIP_VERSION_STR
         print("sip Version:", sipVersion.strip())
-        # always assume, that snapshots are new enough
-        if "snapshot" not in sipVersion:
+        # always assume, that snapshots or dev versions are new enough
+        if "snapshot" not in sipVersion and "dev" not in sipVersion:
             while sipVersion.count('.') < 2:
                 sipVersion += '.0'
             (maj, min, pat) = sipVersion.split('.')
@@ -1186,8 +1201,8 @@ def doDependancyChecks():
         from PyQt5.QtCore import PYQT_VERSION_STR
     pyqtVersion = PYQT_VERSION_STR
     print("PyQt Version:", pyqtVersion.strip())
-    # always assume, that snapshots are new enough
-    if "snapshot" not in pyqtVersion:
+    # always assume, that snapshots or dev versions are new enough
+    if "snapshot" not in pyqtVersion and "dev" not in pyqtVersion:
         while pyqtVersion.count('.') < 2:
             pyqtVersion += '.0'
         (maj, min, pat) = pyqtVersion.split('.')
@@ -1216,8 +1231,8 @@ def doDependancyChecks():
         from PyQt5.Qsci import QSCINTILLA_VERSION_STR
     scintillaVersion = QSCINTILLA_VERSION_STR
     print("QScintilla Version:", QSCINTILLA_VERSION_STR.strip())
-    # always assume, that snapshots are new enough
-    if "snapshot" not in scintillaVersion:
+    # always assume, that snapshots or dev versions are new enough
+    if "snapshot" not in scintillaVersion and "dev" not in scintillaVersion:
         while scintillaVersion.count('.') < 2:
             scintillaVersion += '.0'
         (maj, min, pat) = scintillaVersion.split('.')
@@ -1242,101 +1257,28 @@ def doDependancyChecks():
     print()
 
 
+def __pyName(py_dir, py_file):
+    """
+    Local function to create the Python source file name for the compiled
+    .ui file.
+    
+    @param py_dir suggested name of the directory (string)
+    @param py_file suggested name for the compile source file (string)
+    @return tuple of directory name (string) and source file name (string)
+    """
+    return py_dir, "Ui_{0}".format(py_file)
+
+
 def compileUiFiles():
     """
     Compile the .ui files to Python sources.
-    """                                                 # __IGNORE_WARNING__
+    """
     global sourceDir
-    try:
-        if pyqtVariant == "PyQt4":
-            from PyQt4.uic import compileUiDir
-        else:
-            from PyQt5.uic import compileUiDir
-    except ImportError:
-        if pyqtVariant == "PyQt4":
-            from PyQt4.uic import compileUi
-        else:
-            from PyQt5.uic import compileUi
-        
-        def compileUiDir(dir, recurse=False,            # __IGNORE_WARNING__
-                         map=None, **compileUi_args):
-            """
-            Creates Python modules from Qt Designer .ui files in a directory or
-            directory tree.
-            
-            Note: This function is a modified version of the one found in
-            PyQt5.
-
-            @param dir Name of the directory to scan for files whose name ends
-                with '.ui'. By default the generated Python module is created
-                in the same directory ending with '.py'.
-            @param recurse flag indicating that any sub-directories should be
-                scanned.
-            @param map an optional callable that is passed the name of the
-                directory containing the '.ui' file and the name of the Python
-                module that will be created. The callable should return a
-                tuple of the name of the directory in which the Python module
-                will be created and the (possibly modified) name of the module.
-            @param compileUi_args any additional keyword arguments that are
-                passed to the compileUi() function that is called to create
-                each Python module.
-            """
-            def compile_ui(ui_dir, ui_file):
-                """
-                Local function to compile a single .ui file.
-                
-                @param ui_dir directory containing the .ui file (string)
-                @param ui_file file name of the .ui file (string)
-                """
-                # Ignore if it doesn't seem to be a .ui file.
-                if ui_file.endswith('.ui'):
-                    py_dir = ui_dir
-                    py_file = ui_file[:-3] + '.py'
-
-                    # Allow the caller to change the name of the .py file or
-                    # generate it in a different directory.
-                    if map is not None:
-                        py_dir, py_file = list(map(py_dir, py_file))
-
-                    # Make sure the destination directory exists.
-                    try:
-                        os.makedirs(py_dir)
-                    except:
-                        pass
-
-                    ui_path = os.path.join(ui_dir, ui_file)
-                    py_path = os.path.join(py_dir, py_file)
-
-                    ui_file = open(ui_path, 'r')
-                    py_file = open(py_path, 'w')
-
-                    try:
-                        compileUi(ui_file, py_file, **compileUi_args)
-                    finally:
-                        ui_file.close()
-                        py_file.close()
-
-            if recurse:
-                for root, _, files in os.walk(dir):
-                    for ui in files:
-                        compile_ui(root, ui)
-            else:
-                for ui in os.listdir(dir):
-                    if os.path.isfile(os.path.join(dir, ui)):
-                        compile_ui(dir, ui)
-    
-    def pyName(py_dir, py_file):
-        """
-        Local function to create the Python source file name for the compiled
-        .ui file.
-        
-        @param py_dir suggested name of the directory (string)
-        @param py_file suggested name for the compile source file (string)
-        @return tuple of directory name (string) and source file name (string)
-        """
-        return py_dir, "Ui_{0}".format(py_file)
-    
-    compileUiDir(sourceDir, True, pyName)
+    if pyqtVariant == "PyQt4":
+        from PyQt4.uic import compileUiDir
+    else:
+        from PyQt5.uic import compileUiDir
+    compileUiDir(sourceDir, True, __pyName)
 
 
 def prepareInfoFile(fileName):
@@ -1523,13 +1465,17 @@ def main(argv):
     
     if doCompile:
         print("\nCompiling source files ...")
+        if sys.version_info[0] == 3:
+            skipRe = re.compile(r"DebugClients[\\/]Python[\\/]")
+        else:
+            skipRe = re.compile(r"DebugClients[\\/]Python3[\\/]")
         # Hide compile errors (mainly because of Py2/Py3 differences)
         sys.stdout = io.StringIO()
         if distDir:
             compileall.compile_dir(
                 sourceDir,
                 ddir=os.path.join(distDir, modDir, cfg['ericDir']),
-                rx=re.compile(r"DebugClients[\\/]Python[\\/]"),
+                rx=skipRe,
                 quiet=True)
             py_compile.compile(
                 configName,
@@ -1538,7 +1484,7 @@ def main(argv):
             compileall.compile_dir(
                 sourceDir,
                 ddir=os.path.join(modDir, cfg['ericDir']),
-                rx=re.compile(r"DebugClients[\\/]Python[\\/]"),
+                rx=skipRe,
                 quiet=True)
             py_compile.compile(configName,
                                dfile=os.path.join(modDir, "eric6config.py"))
